@@ -9,27 +9,22 @@
  */
 namespace SebastianBergmann\CodeCoverage\Report;
 
-use function addcslashes;
 use function dirname;
 use function file_put_contents;
 use function serialize;
-use function sprintf;
 use SebastianBergmann\CodeCoverage\CodeCoverage;
-use SebastianBergmann\CodeCoverage\Directory;
 use SebastianBergmann\CodeCoverage\Driver\WriteOperationFailedException;
+use SebastianBergmann\CodeCoverage\Util\Filesystem;
 
 final class PHP
 {
     public function process(CodeCoverage $coverage, ?string $target = null): string
     {
-        $buffer = sprintf(
-            '<?php
-return \unserialize(\'%s\');',
-            addcslashes(serialize($coverage), "'")
-        );
+        $buffer = "<?php
+return \unserialize(<<<'END_OF_COVERAGE_SERIALIZATION'" . PHP_EOL . serialize($coverage) . PHP_EOL . 'END_OF_COVERAGE_SERIALIZATION' . PHP_EOL . ');';
 
         if ($target !== null) {
-            Directory::create(dirname($target));
+            Filesystem::createDirectory(dirname($target));
 
             if (@file_put_contents($target, $buffer) === false) {
                 throw new WriteOperationFailedException($target);
